@@ -8,7 +8,8 @@ from twisted.internet import reactor
 
 
 def run_spider(spider: Spider, pipeline: str = None,
-               settings: dict = None, override: bool = False) -> None:
+               settings: dict = None, override: bool = False,
+               project_name: str = 'scraping') -> None:
     """
     Process for running spiders.
     
@@ -27,11 +28,13 @@ def run_spider(spider: Spider, pipeline: str = None,
     
     if pipeline == 'blob':
         scrapy_settings.update({
-            'ITEM_PIPELINES': {'scraping.scraping.pipelines.BlobUploadPipeline': 1}
+            'ITEM_PIPELINES': {f'{project_name}.{project_name}.pipelines.BlobUploadPipeline': 1}
         })
     elif pipeline == 'download':
         scrapy_settings.update({
-            'ITEM_PIPELINES': {'scraping.scraping.pipelines.FileDownloaderPipeline': 1}
+            'ITEM_PIPELINES': {f'{project_name}.{project_name}.pipelines.FileDownloaderPipeline': 1},
+            'FILES_STORE': 'Khipo-Themis_Project',
+            'FILES_EXPIRES': 0
         })
     
     if settings is not None:
